
import { useState, useEffect, useRef } from 'react';
import { useParams } from 'react-router-dom';
import { Dialog, DialogContent, DialogTitle } from '@/components/ui/dialog';
import { Play } from 'lucide-react';
import LandingHeroImage from "@/components/LandingHeroImage";
import LandingHeroVideo from "@/components/LandingHeroVideo";
import LandingHeroYoutube from "@/components/LandingHeroYoutube";
import FeatureCardsSection from "@/components/FeatureCardsSection";
import LandingHeroSection from "@/components/landing/LandingHeroSection";
import SimpleLandingHeroSection from "@/components/landing/SimpleLandingHeroSection";
import SimpleLandingHeroImage from "@/components/landing/SimpleLandingHeroImage";
import DemoTemplateHeroSection from "@/components/landing/DemoTemplateHeroSection";
import MobileOptimizedHeroSection from "@/components/landing/MobileOptimizedHeroSection";
import MobileOptimizedHeroImage from "@/components/landing/MobileOptimizedHeroImage";
import DemoTemplateFooter from "@/components/landing/DemoTemplateFooter";
import LazyFeatureSection from "@/components/LazyFeatureSection";
import LazyTestimonialSection from "@/components/LazyTestimonialSection";
import LazyCalendlySection from "@/components/LazyCalendlySection";
import CriticalCSS from "@/components/CriticalCSS";
import OptimizedLazySection from "@/components/OptimizedLazySection";
import FastMobileSkeleton from "@/components/FastMobileSkeleton";
import InstantMobileHero from "@/components/InstantMobileHero";
import InstantMobileImage from "@/components/InstantMobileImage";
import InstantSimpleLandingHero from "@/components/InstantSimpleLandingHero";
import FastSimpleLandingImage from "@/components/FastSimpleLandingImage";
import { useOptimizedPageData } from "@/hooks/useOptimizedPageData";
import { Avatar, AvatarFallback, AvatarImage } from '@/components/ui/avatar';
import { MetaTagService } from '@/utils/metaTagService';
import OptimizedSimpleLandingImage from "@/components/OptimizedSimpleLandingImage";

const DynamicLanding = () => {
  const { slug } = useParams();
  
  // Pre-determine page type for instant optimization
  const isMobileOptimized = slug?.includes('mobile') || false;
  const isSimpleLanding = slug?.includes('simple') || false;
  
  // Set default title immediately
  useEffect(() => {
    document.title = 'Rayon.design - CAD for architects';
    
    let titleElement = document.querySelector('title');
    if (titleElement) {
      titleElement.textContent = 'Rayon.design - CAD for architects';
    } else {
      titleElement = document.createElement('title');
      titleElement.textContent = 'Rayon.design - CAD for architects';
      document.head.appendChild(titleElement);
    }
  }, []);

  const { pageData, testimonialData, featureData, loading, error } = useOptimizedPageData();
  const [isVideoModalOpen, setIsVideoModalOpen] = useState(false);
  const [isCalendlyModalOpen, setIsCalendlyModalOpen] = useState(false);
  const [instantRender, setInstantRender] = useState(isMobileOptimized || isSimpleLanding);

  // For optimized pages, show instant content then update when data loads
  useEffect(() => {
    if ((isMobileOptimized || isSimpleLanding) && pageData) {
      // Small delay to prevent flash, then update with real data
      setTimeout(() => setInstantRender(false), 100);
    }
  }, [pageData, isMobileOptimized, isSimpleLanding]);

  const actualStyle = pageData?.style || (isMobileOptimized ? 'mobile-optimized' : (isSimpleLanding ? 'simple-landing' : 'style1'));
  const isMobileOptimizedStyle = actualStyle === 'mobile-optimized';
  const isSimpleLandingStyle = actualStyle === 'simple-landing';

  const socialProofText = pageData?.social_proof_text && pageData.social_proof_text.trim() !== '' 
    ? pageData.social_proof_text 
    : 'Join 100k+ architects';

  // Update document title, favicon, and meta tags when pageData changes
  useEffect(() => {
    if (pageData) {
      // Use the hero tagline (title field) for page title and OG metadata
      const heroTagline = pageData.title.replace(/<[^>]*>/g, ''); // Remove HTML tags from title
      
      // Update all meta tags using the service
      MetaTagService.updatePageMeta(heroTagline, pageData.subtitle, pageData.app_visual_url);
      
      // Set favicon
      MetaTagService.setFavicon('/lovable-uploads/89d533c3-7013-42c7-a7d2-61e7dc688c0b.png');
    }

    // Cleanup function to reset title when component unmounts
    return () => {
      document.title = 'Rayon.design - CAD for architects';
    };
  }, [pageData]);

  const handleWatchDemo = () => {
    setIsVideoModalOpen(true);
  };

  const handleOpenCalendlyModal = () => {
    setIsCalendlyModalOpen(true);
  };

  const processTitle = (title: string) => {
    return title.replace(/<a>(.*?)<\/a>/g, '<span style="color: #F7CFF2">$1</span>');
  };

  const extractVimeoId = (url: string) => {
    const match = url.match(/vimeo\.com\/(\d+)/);
    return match ? match[1] : null;
  };

  const renderLogos = () => {
    const logoUrls = pageData?.logo_urls || [];
    const validLogos = logoUrls.filter(url => url && url.trim() !== '');
    
    if (validLogos.length === 0) {
      const logoNames = ['Asterisk', 'Books', 'Opal', 'Dune', 'Oasis', 'Vertex'];
      return (
        <div className="flex items-center justify-center space-x-8 opacity-40">
          {logoNames.map((name, index) => (
            <div key={index} className="text-gray-400 text-lg font-medium">
              {name}
            </div>
          ))}
        </div>
      );
    }

    return (
      <div className="flex items-center justify-center space-x-8 opacity-60">
        {validLogos.map((logoUrl, index) => (
          <div key={index} className="h-8 w-auto flex items-center justify-center">
            <img 
              src={logoUrl} 
              alt={`Company logo ${index + 1}`} 
              className="max-h-8 w-auto object-contain filter grayscale" 
              loading="lazy"
            />
          </div>
        ))}
      </div>
    );
  };

  const renderGetStartedSection = () => (
    <OptimizedLazySection className="py-16 px-4 sm:px-6 lg:px-8">
      {actualStyle === 'demo-template' ? (
        <DemoTemplateFooter
          ctaText={pageData?.cta_text || 'Start Building'}
          secondaryCtaText={pageData?.secondary_cta_text || 'Book a demo'}
          secondaryCtaUrl={pageData?.secondary_cta_url || 'https://calendly.com/support-demo-jvo/rayon-demo-premium-eu-clone-1'}
          socialProofText={socialProofText}
          renderLogos={renderLogos}
          onPrimaryClick={handleOpenCalendlyModal}
        />
      ) : (
        <div className="max-w-7xl mx-auto px-4 sm:px-6 lg:px-8">
          <div className="max-w-4xl mx-auto text-center">
            {/* Social Proof */}
            <div className="flex items-center justify-center mb-8">
              <div className="flex -space-x-2">
                <Avatar className="w-8 h-8 border-2 border-gray-700">
                  <AvatarImage src="https://images.unsplash.com/photo-1472099645785-5658abf4ff4e?w=150&h=150&fit=crop&crop=face" loading="lazy" />
                  <AvatarFallback>U1</AvatarFallback>
                </Avatar>
                <Avatar className="w-8 h-8 border-2 border-gray-700">
                  <AvatarImage src="https://images.unsplash.com/photo-1494790108755-2616b612b1f5?w=150&h=150&fit=crop&crop=face" loading="lazy" />
                  <AvatarFallback>U2</AvatarFallback>
                </Avatar>
                <Avatar className="w-8 h-8 border-2 border-gray-700">
                  <AvatarImage src="https://images.unsplash.com/photo-1507003211169-0a1dd7228f2d?w=150&h=150&fit=crop&crop=face" loading="lazy" />
                  <AvatarFallback>U3</AvatarFallback>
                </Avatar>
                <Avatar className="w-8 h-8 border-2 border-gray-700">
                  <AvatarImage src="https://images.unsplash.com/photo-1438761681033-6461ffad8d80?w=150&h=150&fit=crop&crop=face" loading="lazy" />
                  <AvatarFallback>U4</AvatarFallback>
                </Avatar>
                <div className="w-8 h-8 rounded-full bg-gray-700 border-2 border-gray-700 flex items-center justify-center text-xs text-gray-300">
                  +
                </div>
              </div>
              <span className="ml-3 text-sm text-gray-400">
                {socialProofText}
              </span>
            </div>
            <h1 className="text-5xl md:text-7xl font-bold leading-[0.85] mb-8 tracking-tighter text-white">
              Get Started with Rayon Today
            </h1>
            <div className="max-w-2xl mx-auto mb-12">
              <p className="text-xl text-gray-400 leading-relaxed mb-4">Try the software for free today.</p>
            </div>
            <div className="flex items-center justify-center space-x-4 mb-16">
              <a 
                href={pageData?.cta_url || 'https://rayon.design/'} 
                target="_blank" 
                rel="noopener noreferrer"
                className="bg-white text-gray-900 px-8 py-4 md:px-12 md:py-6 rounded-lg font-semibold hover:bg-gray-100 transition-colors text-sm md:text-lg inline-block text-center no-underline"
              >
                {pageData?.cta_text || 'Start building'}
              </a>
              <a 
                href={pageData?.secondary_cta_url || 'https://calendly.com/support-demo-jvo/rayon-demo-premium-eu-clone-1'} 
                target="_blank" 
                rel="noopener noreferrer"
                className="bg-gray-800 text-white px-8 py-4 md:px-12 md:py-6 rounded-lg font-semibold hover:bg-gray-700 transition-colors border border-gray-700 text-sm md:text-lg inline-block text-center no-underline"
              >
                {pageData?.secondary_cta_text || 'Book a demo'}
              </a>
            </div>
            
            {/* Logo Banner - Static on desktop, animated carousel on mobile */}
            <div className="mb-16 py-8 md:py-4">
              {/* Desktop: Static logos */}
              <div className="hidden md:block">
                {renderLogos()}
              </div>
              
              {/* Mobile: Animated carousel */}
              <div className="block md:hidden overflow-hidden">
                <div className="animate-scroll-left-footer flex items-center space-x-8 w-max">
                  {renderLogos()}
                  {/* Duplicate logos for seamless loop */}
                  {renderLogos()}
                </div>
              </div>
              
              <style dangerouslySetInnerHTML={{
                __html: `
                  @keyframes scroll-left-footer {
                    0% {
                      transform: translateX(0);
                    }
                    100% {
                      transform: translateX(-50%);
                    }
                  }
                  
                  .animate-scroll-left-footer {
                    animation: scroll-left-footer 20s linear infinite;
                  }
                  
                  .animate-scroll-left-footer:hover {
                    animation-play-state: paused;
                  }
                `
              }} />
            </div>
          </div>
        </div>
      )}
    </OptimizedLazySection>
  );

  // Show error state if there's an error
  if (error) {
    return (
      <div className="min-h-screen bg-gray-900 flex items-center justify-center">
        <div className="text-white font-['Geist'] text-center">
          <h1 className="text-2xl mb-4">Error Loading Page</h1>
          <p className="text-gray-400">{error}</p>
        </div>
      </div>
    );
  }

  // Instant render for simple landing pages
  if (isSimpleLandingStyle && instantRender) {
    return (
      <div 
        className="simple-landing-instant min-h-screen bg-gray-900 text-white font-['Geist'] relative"
        style={{
          backgroundImage: "url(/lovable-uploads/c00ddefc-b244-4071-97eb-05021ebc4b89.png)",
          backgroundSize: "auto",
          backgroundRepeat: "repeat",
          backgroundPosition: "top left"
        }}
      >
        <CriticalCSS />
        <div className="absolute inset-0 bg-gray-900/90 z-0"></div>
        <div className="relative z-10">
          <InstantSimpleLandingHero />
          <FastSimpleLandingImage onWatchDemo={handleWatchDemo} />
          
          {/* Instant sections */}
          <div className="px-4">
            <FastMobileSkeleton />
          </div>
          
          {/* Video Modal */}
          <Dialog open={isVideoModalOpen} onOpenChange={setIsVideoModalOpen}>
            <DialogContent className="max-w-4xl p-0 bg-black border-0">
              <div className="aspect-video w-full h-full">
                <iframe
                  src="https://player.vimeo.com/video/1091321536?autoplay=1&controls=1&loop=1"
                  width="100%"
                  height="100%"
                  frameBorder="0"
                  allow="autoplay; fullscreen; picture-in-picture"
                  allowFullScreen
                  title="Demo Video"
                  className="rounded-lg"
                ></iframe>
              </div>
            </DialogContent>
          </Dialog>
        </div>
      </div>
    );
  }

  // Instant render for mobile-optimized pages
  if (isMobileOptimizedStyle && instantRender) {
    return (
      <div className="min-h-screen bg-gray-900 text-white font-['Geist'] relative max-w-md mx-auto">
        <CriticalCSS />
        <div className="absolute inset-0 bg-gray-900/90 z-0"></div>
        <div className="relative z-10">
          <InstantMobileHero />
          <InstantMobileImage onWatchDemo={handleWatchDemo} />
          
          {/* Instant sections */}
          <div className="px-4">
            <FastMobileSkeleton />
          </div>
          
          {/* Video Modal */}
          <Dialog open={isVideoModalOpen} onOpenChange={setIsVideoModalOpen}>
            <DialogContent className="w-[100vw] h-[60vh] max-w-none m-0 top-[50%] left-[50%] translate-x-[-50%] translate-y-[-50%] p-0 bg-black border-0">
              <div className="aspect-video w-full h-full">
                <iframe
                  src="https://player.vimeo.com/video/1091321536?autoplay=1&controls=1&loop=1"
                  width="100%"
                  height="100%"
                  frameBorder="0"
                  allow="autoplay; fullscreen; picture-in-picture"
                  allowFullScreen
                  title="Demo Video"
                  className="rounded-lg"
                />
              </div>
            </DialogContent>
          </Dialog>
        </div>
      </div>
    );
  }

  // Regular render for all other pages or after data loads
  return (
    <div 
      className={`min-h-screen bg-gray-900 text-white font-['Geist'] relative ${
        isMobileOptimizedStyle ? 'max-w-md mx-auto' : ''
      }`}
      style={{
        backgroundImage: isMobileOptimizedStyle ? "none" : "url(/lovable-uploads/c00ddefc-b244-4071-97eb-05021ebc4b89.png)",
        backgroundSize: "auto",
        backgroundRepeat: "repeat",
        backgroundPosition: "top left"
      }}
    >
      <CriticalCSS />
      <div className="absolute inset-0 bg-gray-900/90 z-0"></div>
      <div className="relative z-10">
        {/* Hero Section */}
        {actualStyle === 'demo-template' ? (
          <DemoTemplateHeroSection
            title={pageData?.title || 'CAD for architects. But much better...'}
            subtitle={pageData?.subtitle || 'Meet the system for modern architectural development.'}
            ctaText={pageData?.cta_text || 'Start Building'}
            ctaUrl={pageData?.cta_url || 'https://rayon.design/'}
            secondaryCtaText={pageData?.secondary_cta_text || 'Book a demo'}
            secondaryCtaUrl={pageData?.secondary_cta_url || 'https://calendly.com/support-demo-jvo/rayon-demo-premium-eu-clone-1'}
            socialProofText={socialProofText}
            processTitle={processTitle}
            renderLogos={renderLogos}
          />
        ) : isSimpleLandingStyle ? (
          <SimpleLandingHeroSection
            title={pageData?.title || 'CAD for architects. But much better...'}
            subtitle={pageData?.subtitle || 'Meet the system for modern architectural development.'}
            ctaText={pageData?.cta_text || 'Start Building'}
            ctaUrl={pageData?.cta_url || 'https://rayon.design/'}
            secondaryCtaText={pageData?.secondary_cta_text || 'Book a demo'}
            secondaryCtaUrl={pageData?.secondary_cta_url || 'https://calendly.com/support-demo-jvo/rayon-demo-premium-eu-clone-1'}
            socialProofText={socialProofText}
            processTitle={processTitle}
            renderLogos={renderLogos}
          />
        ) : isMobileOptimizedStyle ? (
          <MobileOptimizedHeroSection
            title={pageData?.title || 'CAD for architects. But much better...'}
            subtitle={pageData?.subtitle || 'Meet the system for modern architectural development.'}
            ctaText={pageData?.cta_text || 'Start Building'}
            ctaUrl={pageData?.cta_url || 'https://rayon.design/'}
            secondaryCtaText={pageData?.secondary_cta_text || 'Book a demo'}
            secondaryCtaUrl={pageData?.secondary_cta_url || 'https://calendly.com/support-demo-jvo/rayon-demo-premium-eu-clone-1'}
            socialProofText={socialProofText}
            processTitle={processTitle}
            renderLogos={renderLogos}
          />
        ) : (
          <LandingHeroSection 
            title={pageData?.title || 'CAD for architects. But much better...'} 
            subtitle={pageData?.subtitle || 'Meet the system for modern architectural development.'} 
            ctaText={pageData?.cta_text || 'Start Building'} 
            ctaUrl={pageData?.cta_url || 'https://rayon.design/'}
            secondaryCtaText={pageData?.secondary_cta_text || 'Book a demo'}
            secondaryCtaUrl={pageData?.secondary_cta_url || 'https://calendly.com/support-demo-jvo/rayon-demo-premium-eu-clone-1'} 
            socialProofText={socialProofText}
            processTitle={processTitle} 
            handleStartBuilding={() => {}}
            handleBookDemo={() => {}}
            renderLogos={renderLogos} 
          />
        )}

        {/* Hero Visual */}
        {pageData && (
          <>
            {pageData.style === 'video-landing' && pageData.video_url && (
              <LandingHeroVideo vimeoId={extractVimeoId(pageData.video_url)!} />
            )}
            
            {pageData.style === 'youtube-template' && pageData.youtube_url && (
              <LandingHeroYoutube youtubeUrl={pageData.youtube_url} />
            )}
            
            {isMobileOptimizedStyle && pageData.app_visual_url && (
              <MobileOptimizedHeroImage appVisualUrl={pageData.app_visual_url} onWatchDemo={handleWatchDemo} />
            )}
            
            {isSimpleLandingStyle && pageData.app_visual_url && (
              <FastSimpleLandingImage appVisualUrl={pageData.app_visual_url} onWatchDemo={handleWatchDemo} />
            )}
            
            {(pageData.style === 'style1' || pageData.style === 'demo-template') && pageData.app_visual_url && (
              <LandingHeroImage appVisualUrl={pageData.app_visual_url} onWatchDemo={handleWatchDemo} />
            )}
          </>
        )}

        {/* Content sections */}
        {(pageData || isMobileOptimizedStyle) && (
          <>
            {/* Feature Section */}
            {isMobileOptimizedStyle ? (
              <div className="px-4">
                <LazyFeatureSection cards={featureData} />
              </div>
            ) : (
              <OptimizedLazySection>
                <LazyFeatureSection cards={featureData} />
              </OptimizedLazySection>
            )}
            
            {/* Testimonial Section */}
            {isMobileOptimizedStyle ? (
              <div className="px-4">
                <LazyTestimonialSection 
                  cards={testimonialData} 
                  socialProofText={socialProofText}
                />
              </div>
            ) : (
              <OptimizedLazySection>
                <LazyTestimonialSection 
                  cards={testimonialData} 
                  socialProofText={socialProofText}
                />
              </OptimizedLazySection>
            )}

            {/* Video Modal Dialog */}
            {(pageData?.style === 'style1' || pageData?.style === 'simple-landing' || pageData?.style === 'demo-template' || isMobileOptimizedStyle) && (
              <Dialog open={isVideoModalOpen} onOpenChange={setIsVideoModalOpen}>
                <DialogContent className={`p-0 bg-black border-0 ${
                  isMobileOptimizedStyle 
                    ? 'w-[100vw] h-[60vh] max-w-none m-0 top-[50%] left-[50%] translate-x-[-50%] translate-y-[-50%]' 
                    : 'max-w-4xl'
                }`}>
                  <div className="aspect-video w-full h-full">
                    <iframe
                      src="https://player.vimeo.com/video/1091321536?autoplay=1&controls=1&loop=1"
                      width="100%"
                      height="100%"
                      frameBorder="0"
                      allow="autoplay; fullscreen; picture-in-picture"
                      allowFullScreen
                      title="Demo Video"
                      className="rounded-lg"
                    ></iframe>
                  </div>
                </DialogContent>
              </Dialog>
            )}

            {/* Calendly Modal Dialog for demo-template */}
            {pageData?.style === 'demo-template' && (
              <Dialog open={isCalendlyModalOpen} onOpenChange={setIsCalendlyModalOpen}>
                <DialogContent className="max-w-4xl h-[80vh] p-0 bg-white border-0">
                  <DialogTitle className="sr-only">Schedule a Meeting</DialogTitle>
                  {pageData.cta_url && pageData.cta_url.trim() !== '' ? (
                    <iframe
                      src={pageData.cta_url}
                      width="100%"
                      height="100%"
                      frameBorder="0"
                      title="Schedule a Meeting"
                      className="rounded-lg"
                    />
                  ) : (
                    <div className="flex items-center justify-center h-full">
                      <p className="text-gray-600">Calendly URL not configured</p>
                    </div>
                  )}
                </DialogContent>
              </Dialog>
            )}

            {/* Legacy Feature Cards Section for backward compatibility */}
            {pageData?.feature_cards && Array.isArray(pageData.feature_cards) && 
             pageData.feature_cards.some(fc => fc.title || fc.text || fc.image_url) && (
              <FeatureCardsSection 
                cards={pageData.feature_cards.map(fc => ({
                  title: fc.title ?? "",
                  text: fc.text ?? "",
                  image_url: fc.image_url ?? ""
                }))} 
              />
            )}

            {/* Calendly Section - Only use embed_url if available */}
            {pageData?.embed_url && !isMobileOptimizedStyle && (
              <OptimizedLazySection>
                <LazyCalendlySection embedUrl={pageData.embed_url} />
              </OptimizedLazySection>
            )}
            
            {/* Get Started Section */}
            {isMobileOptimizedStyle ? (
              <div className="py-16 px-4">
                <div className="max-w-md mx-auto text-center">
                  <div className="space-y-4 mb-8">
                    <h2 className="text-2xl font-bold text-white">Ready to get started?</h2>
                    <p className="text-gray-400">Join thousands of architects already using Rayon.</p>
                  </div>
                  <div className="space-y-3">
                    <a 
                      href={pageData?.cta_url || 'https://rayon.design/'} 
                      target="_blank" 
                      rel="noopener noreferrer"
                      className="block w-full bg-blue-600 text-white py-4 px-6 rounded-xl font-semibold hover:bg-blue-700 transition-colors text-lg text-center no-underline shadow-lg"
                    >
                      {pageData?.cta_text || 'Start building'}
                    </a>
                    <a 
                      href={pageData?.secondary_cta_url || 'https://calendly.com/support-demo-jvo/rayon-demo-premium-eu-clone-1'} 
                      target="_blank" 
                      rel="noopener noreferrer"
                      className="block w-full bg-gray-800 text-white py-4 px-6 rounded-xl font-semibold hover:bg-gray-700 transition-colors border border-gray-700 text-lg text-center no-underline"
                    >
                      {pageData?.secondary_cta_text || 'Book a demo'}
                    </a>
                  </div>
                </div>
              </div>
            ) : (
              renderGetStartedSection()
            )}

            {/* Footer */}
            <footer className="py-12 px-4 sm:px-6 lg:px-8 border-t border-gray-800">
              <div className="max-w-6xl mx-auto text-center">
                <p className="text-gray-400">
                  © 2025 Rayon.design
                </p>
              </div>
            </footer>
          </>
        )}
      </div>
    </div>
  );
};

export default DynamicLanding;
